Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(38)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePhoneTest.java

Issue 2766413003: test (Closed)
Patch Set: format Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePhoneTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePhoneTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePhoneTest.java
index b9ca552b68e434f8b511688ecf579aae2a497950..5598aef4eaae56d9f3c6300653577b9eeab51133 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePhoneTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePhoneTest.java
@@ -55,7 +55,7 @@ public class PaymentRequestIncompletePhoneTest extends PaymentRequestTestBase {
setTextInEditorAndWait(new String[] {"---"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);
- assertEquals(PaymentRequestSection.EDIT_BUTTON_SELECT, getContactDetailsButtonState());
+ assertEquals(PaymentRequestSection.EDIT_BUTTON_CHOOSE, getContactDetailsButtonState());
clickAndWait(R.id.close_button, mDismissed);
expectResultContains(new String[] {"Request cancelled"});
@@ -77,9 +77,9 @@ public class PaymentRequestIncompletePhoneTest extends PaymentRequestTestBase {
clickInContactInfoAndWait(R.id.payments_add_option_button, mReadyToEdit);
setTextInEditorAndWait(new String[] {"---"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
// The section collapses and the [SELECT] button is active.
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);
- assertEquals(PaymentRequestSection.EDIT_BUTTON_SELECT, getContactDetailsButtonState());
+ assertEquals(PaymentRequestSection.EDIT_BUTTON_CHOOSE, getContactDetailsButtonState());
clickAndWait(R.id.close_button, mDismissed);
expectResultContains(new String[] {"Request cancelled"});
@@ -77,9 +77,9 @@ public class PaymentRequestIncompletePhoneTest extends PaymentRequestTestBase {
setTextInEditorAndWait(new String[] {"---"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
- // The section collapses and the [SELECT] button is active.
+ // The section collapses and the [CHOOSE] button is active.
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);

Powered by Google App Engine
This is Rietveld 408576698